<?php

/**
 * @file
 */

use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;

/**
 * Implements hook_form_FORM_ID_alter.
 *
 * @param array $form
 * @param \Drupal\Core\Form\FormStateInterface $form_state
 */
function default_menu_link_form_node_type_form_alter(array &$form, FormStateInterface $form_state) {

  // Retrieve the entity to be able to store data.
  $type = $form_state->getFormObject()->getEntity();

  // A new tab needs to be created to avoid issues with the default ajax calls on the menu settings tab.
  if (!isset($form['menu_options'])) {
    $form['menu_options'] = [
      '#type' => 'details',
      '#title' => t('Menu options'),
      '#group' => 'additional_settings',
    ];
  }

  // Add a checkbox to the existing menu items.
  $form['menu_options']['default_menu_link_enabled'] = [
    '#type' => 'checkbox',
    '#title' => t('Default the "Provide a menu link" item to checked.'),
    '#description' => t('Enable the "Provide a menu link" checkbox by default.'),
    '#default_value' => $type->getThirdPartySetting('default_menu_link', 'default_menu_link_enabled', FALSE),
  ];

  // Add a submit handler to store the custom checkbox.
  $form['actions']['submit']['#submit'][] = 'default_menu_link_form_node_type_form_submit';
}

/**
 * Form submit handler function for default_menu_link_form_node_type_form_alter().
 */
function default_menu_link_form_node_type_form_submit(&$form, FormStateInterface $form_state) {
  $bundle = $form['type']['#default_value'];
  $node_type = NodeType::load($bundle);
  $node_type->setThirdPartySetting('default_menu_link', 'default_menu_link_enabled', $form_state->getValue('default_menu_link_enabled'));
  $node_type->save();

  // Without a cache clear, it seems the above save doesn't really take effect.
  // TODO: Find a better way to do this instead of clearing the entire Drupal cache.
  drupal_flush_all_caches();
}
